@@ -77,6 +77,7 @@ class Variable:
         self.__value = value
         return None
 
+
 class Style:
     """
     Documentation
@@ -174,6 +175,13 @@ class Style:
         """
         return self.__border
 
+    def rename(self):
+        """
+        Documentation
+        """
+        self.__name =  chr(self.__column+64)+str(self.__row)
+    return None
+
 class Model:
     """
     Documentation
@@ -228,6 +236,10 @@ class Model:
                 value = self.__worksheet.row_dimensions[number].height
                 self.__rows_height.append(Variable(number, cell.row, cell.column, value))
 
+        self.__mergedcells = []
+        for range in self.__worksheet.merged_cells.ranges:
+            self.__mergedcells.append(Variable(str(range), None, None, range))
+
     @property
     def rows(self):
         """
@@ -293,10 +305,28 @@ class Model:
         Documentation
         """
         ranges = []
-        for range in self.__worksheet.merged_cells.ranges:
-            ranges.append(str(range))
+        for range in self.__mergedcells:
+            ranges.append(range.name)
         return ranges
 
+    def remerge(self, sizetables):
+        """
+        Documentation
+        """
+        for sizetable in sizetables:
+            for range in self.mergedcells:
+                incell = [range.split(':')[0],range.split(':')[1]]
+                outcell = []
+                for cell in incell:
+                    cell_column = cell[0]
+                    cell_row = int(cell[1:len(cell)])
+                    if cell_row > sizetable[0]:
+                        cell_row = cell_row + sizetable[1]
+                    outcell.append(cell_column+str(cell_row))
+                self.variable(range).name = outcell[0]+':'+str(outcell[1])
+                self.variable(range).value = outcell[0]+':'+str(outcell[1])
+    return None
+
     @property
     def variables(self):
         """
@@ -343,7 +373,7 @@ class Model:
             rows_height.append([row.name, row.value])
         return rows_height
 
-    def calculating_rows(self, data):
+    def sizetables(self, data):
         """
         Documentation
         """
@@ -369,35 +399,39 @@ class Model:
         result = []
         for key in tables:
             result.append([int(key.split(':')[0]),int(key.split(':')[1])])
-        for el in result:
-            for variable in self.__variables:
-                if variable.row >= int(el[0]):
-                    variable.row = variable.row + int(el[1])
-            for style in self.__styles:
-                if style.row >= int(el[0]):
-                    style.row = style.row + int(el[1])
+        return result
 
+    def update(self, sizetables):
+        """
+        Documentation
+        """
+        self.remerge(sizetables)
+        for sizetable in sizetables:
+            self.rows = self.rows + sizetable[1]
+            for variable in self.variables:
+                if variable.row > sizetable[0]:
+                    variable.row = variable.row + sizetable[1]
+                if style.row > sizetable[0]:
+                    style.row = style.row + sizetable[1]
+                    style.rename()
         return None
 
     def import_data(self, data):
         """
         Documentation
-
+        """
 
         for variable in self.variables:
             if variable.name in data:
                 variable.value = data[variable.name]
             elif 'table' in data:
+                print()
+#                for tbl in data['table']:
+#                    n = 0
+#                    for variable2 in self.variables:
+#                        if variable.name
+#                    if variable.name in data['table']:
 
-
-                for tbl in data['table']:
-                    n = 0
-                    for variable2 in self.variables:
-                        if variable.name
-                    if variable.name in data['table']:
-
-                for variable in self.variables:
-                    if variable.row >"""
         return None
 
     def past_in_worksheet(self,worksheet):
